#pragma once

#include <stddef.h>

#ifdef __cplusplus
extern "C" {
#endif

// Display help information
int help(const unsigned char *manpage, size_t manpage_len);

#ifdef __cplusplus
}
#endif
